---
name: Question
about: Describe this issue template's purpose here.
title: ''
labels: question
assignees: ''

---

### Question
<!-- Describe this issue template's purpose here. -->

### Additional context
<!-- Add any other context or screenshots about the feature request here. -->
<!-- This part is optional. -->


### Checklist

- [ ] Check out our [contributing guidelines](https://github.com/astropy/astropy/blob/master/CONTRIBUTING.md).
- [ ] Check out our [code of conduct](https://github.com/astropy/astropy/blob/master/CODE_OF_CONDUCT.md).
- [ ] Search the GitHub repository to see if a similar issue has already been posted. If a similar issue is closed, have a quick look to see if you are satisfied by the resolution. If not please go ahead and open an issue!
